# encoding: utf-8

'''

This module contains the meta-data of the library.

'''

__author__ = 'David Kundih'
__copyright__ = 'Copyright © 2021-2022 David Kundih'
__credits__ = [
	'dkundih <https://github.com/dkundih>',

]
__license__ = 'Copyright © 2021-2022 David Kundih. All rights reserved. Licensed under the Apache License, Version 2.0 | For more details about the license and terms of use visit the official dystopia documentation linked at https://github.com/dkundih/dystopia and https://pypi.org/project/dystopia'
__version__ = '0.0.1'
__documentation__ = 'https://github.com/dkundih/dystopia | https://pypi.org/project/dystopia'
__contact__ = 'dakundih@unin.hr | kundihdavid@gmail.com'
__donate__ = 'https://patreon.com/dkundih | https://buymeacoffee.com/dkundih'
__APPversion__ = 'None'
